@@ -1,6 +1,7 @@
 """Authentication backends for Django FIDO."""
 import base64
 import logging
+from abc import ABC, abstractmethod
 from typing import Any, Dict, Optional
 
 from django.contrib import messages
@@ -12,6 +13,7 @@ from django.http import HttpRequest
 from django.utils.translation import gettext_lazy as _
 from fido2.server import Fido2Server
 
+from .models import Authenticator
 from .settings import SETTINGS
 
 _LOGGER = logging.getLogger(__name__)
@@ -26,15 +28,44 @@ def is_fido_backend_used() -> bool:
     return False
 
 
-class Fido2AuthenticationBackend(object):
+class BaseFido2AuthenticationBackend(ABC):
     """
-    Authenticate user using FIDO 2.
+    Base class for authenticating user using FIDO 2.
 
     @cvar counter_error_message: Error message in case FIDO 2 device counter didn't increase.
     """
 
     counter_error_message = _("Counter of the FIDO 2 device decreased. Device may have been duplicated.")
 
+    @abstractmethod
+    def authenticate(self, request: HttpRequest, user: AbstractBaseUser, fido2_server: Fido2Server,
+                     fido2_state: Dict[str, bytes], fido2_response: Dict[str, Any]) -> Optional[AbstractBaseUser]:
+        """Authenticate to be implemented."""
+        raise NotImplementedError
+
+    def mark_device_used(self, device, counter):
+        """Update FIDO 2 device usage information."""
+        if counter == 0 and device.counter == 0:
+            # Counter is unsupported by the device, bail out early
+            return
+        if counter <= device.counter:
+            _LOGGER.info("FIDO 2 authentication failed because of not increasing counter.")
+            raise ValueError("Counter didn't increase.")
+        device.counter = counter
+        device.full_clean()
+        device.save()
+
+    def get_user(self, user_id):
+        """Return user based on its ID."""
+        try:
+            return get_user_model().objects.get(pk=user_id)
+        except get_user_model().DoesNotExist:
+            return None
+
+
+class Fido2AuthenticationBackend(BaseFido2AuthenticationBackend):
+    """Authenticate user using FIDO 2."""
+
     def authenticate(self, request: HttpRequest, user: AbstractBaseUser, fido2_server: Fido2Server,
                      fido2_state: Dict[str, bytes], fido2_response: Dict[str, Any]) -> Optional[AbstractBaseUser]:
         """Authenticate using FIDO 2."""
@@ -56,24 +87,36 @@ class Fido2AuthenticationBackend(object):
             raise PermissionDenied("Counter didn't increase.")
         return user
 
-    def mark_device_used(self, device, counter):
-        """Update FIDO 2 device usage information."""
-        if counter == 0 and device.counter == 0:
-            # Counter is unsupported by the device, bail out early
-            return
-        if counter <= device.counter:
-            _LOGGER.info("FIDO 2 authentication failed because of not increasing counter.")
-            raise ValueError("Counter didn't increase.")
-        device.counter = counter
-        device.full_clean()
-        device.save()
 
-    def get_user(self, user_id):
-        """Return user based on its ID."""
+class Fido2PasswordlessAuthenticationBackend(BaseFido2AuthenticationBackend):
+    """Authenticate user using FIDO 2 passwordlessly using supplied user handle."""
+
+    def authenticate(self, request: HttpRequest, user: Optional[AbstractBaseUser], fido2_server: Fido2Server,
+                     fido2_state: Dict[str, bytes], fido2_response: Dict[str, Any]) -> Optional[AbstractBaseUser]:
+        """Authenticate using FIDO 2."""
+        user_handle = fido2_response['user_handle']
+
         try:
-            return get_user_model().objects.get(pk=user_id)
-        except get_user_model().DoesNotExist:
+            device = Authenticator.objects.get(user_handle=user_handle)
+            user = device.user
+            credentials = [device.credential]
+            fido2_server.authenticate_complete(
+                fido2_state, credentials, fido2_response['credential_id'], fido2_response['client_data'],
+                fido2_response['authenticator_data'], fido2_response['signature'])
+        except ValueError as error:
+            _LOGGER.info("FIDO 2 authentication failed with error: %r", error)
             return None
+        except Authenticator.DoesNotExist:
+            _LOGGER.info("FIDO 2 authentication could not find user handle: %s", user_handle)
+            return None
+
+        try:
+            self.mark_device_used(device, fido2_response['authenticator_data'].counter)
+        except ValueError:
+            # Raise `PermissionDenied` to stop the authentication process and skip remaining backends.
+            messages.error(request, self.counter_error_message)
+            raise PermissionDenied("Counter didn't increase.")
+        return user
 
 
 class Fido2GeneralAuthenticationBackend(ModelBackend):
